==> qtjambi-uic-6.3.2-sources.jar: io/qt/uic/ui4/DomColor.java <==
package io.qt.uic.ui4;


/**
 * <p>Java wrapper for Qt class DomColor</p>
 */
public class DomColor extends io.qt.QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public DomColor(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomColor instance);
    
    @io.qt.QtUninvokable
    public final int attributeAlpha(){
        return attributeAlpha_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int attributeAlpha_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearAttributeAlpha(){
        clearAttributeAlpha_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearAttributeAlpha_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearElementBlue(){
        clearElementBlue_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementBlue_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearElementGreen(){
        clearElementGreen_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementGreen_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearElementRed(){
        clearElementRed_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementRed_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int elementBlue(){
        return elementBlue_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int elementBlue_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int elementGreen(){
        return elementGreen_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int elementGreen_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int elementRed(){
        return elementRed_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int elementRed_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasAttributeAlpha(){
        return hasAttributeAlpha_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasAttributeAlpha_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementBlue(){
        return hasElementBlue_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementBlue_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementGreen(){
        return hasElementGreen_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementGreen_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementRed(){
        return hasElementRed_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementRed_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void read(io.qt.core.QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @io.qt.QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    @io.qt.QtUninvokable
    public final void setAttributeAlpha(int a){
        setAttributeAlpha_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setAttributeAlpha_native_int(long __this__nativeId, int a);
    
    @io.qt.QtUninvokable
    public final void setElementBlue(int a){
        setElementBlue_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementBlue_native_int(long __this__nativeId, int a);
    
    @io.qt.QtUninvokable
    public final void setElementGreen(int a){
        setElementGreen_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementGreen_native_int(long __this__nativeId, int a);
    
    @io.qt.QtUninvokable
    public final void setElementRed(int a){
        setElementRed_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementRed_native_int(long __this__nativeId, int a);
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = ""</code>.</p>
     */
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer) {
        write(writer, "");
    }
    
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer, java.lang.String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @io.qt.QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected DomColor(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-uic-6.4.3-sources.jar: io/qt/uic/ui4/DomColor.java <==
package io.qt.uic.ui4;


/**
 * <p>Java wrapper for Qt class DomColor</p>
 */
public class DomColor extends io.qt.QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public DomColor(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomColor instance);
    
    @io.qt.QtUninvokable
    public final int attributeAlpha(){
        return attributeAlpha_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int attributeAlpha_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearAttributeAlpha(){
        clearAttributeAlpha_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearAttributeAlpha_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearElementBlue(){
        clearElementBlue_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementBlue_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearElementGreen(){
        clearElementGreen_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementGreen_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearElementRed(){
        clearElementRed_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementRed_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int elementBlue(){
        return elementBlue_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int elementBlue_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int elementGreen(){
        return elementGreen_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int elementGreen_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int elementRed(){
        return elementRed_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int elementRed_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasAttributeAlpha(){
        return hasAttributeAlpha_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasAttributeAlpha_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementBlue(){
        return hasElementBlue_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementBlue_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementGreen(){
        return hasElementGreen_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementGreen_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementRed(){
        return hasElementRed_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementRed_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void read(io.qt.core.QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @io.qt.QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    @io.qt.QtUninvokable
    public final void setAttributeAlpha(int a){
        setAttributeAlpha_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setAttributeAlpha_native_int(long __this__nativeId, int a);
    
    @io.qt.QtUninvokable
    public final void setElementBlue(int a){
        setElementBlue_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementBlue_native_int(long __this__nativeId, int a);
    
    @io.qt.QtUninvokable
    public final void setElementGreen(int a){
        setElementGreen_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementGreen_native_int(long __this__nativeId, int a);
    
    @io.qt.QtUninvokable
    public final void setElementRed(int a){
        setElementRed_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementRed_native_int(long __this__nativeId, int a);
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
    
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer, java.lang.String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @io.qt.QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected DomColor(QPrivateConstructor p) { super(p); } 
    
}
